Request archival
----------------

.. autosimple:: swh.web.add_forge_now.api_views.api_add_forge_request_create

.. autosimple:: swh.web.add_forge_now.api_views.api_add_forge_request_update

.. autosimple:: swh.web.add_forge_now.api_views.api_add_forge_request_list

.. autosimple:: swh.web.add_forge_now.api_views.api_add_forge_request_get

.. autosimple:: swh.web.add_forge_now.api_views.api_add_forge_request_create

.. autosimple:: swh.web.save_bulk.api_views.api_origin_save_bulk

.. autosimple:: swh.web.save_bulk.api_views.api_origin_save_bulk_requests

.. autosimple:: swh.web.save_bulk.api_views.api_origin_save_bulk_request_info

.. autosimple:: swh.web.save_code_now.api_views.api_save_origin

.. autosimple:: swh.web.save_origin_webhooks.bitbucket.api_origin_save_webhook_bitbucket

.. autosimple:: swh.web.save_origin_webhooks.gitea.api_origin_save_webhook_gitea

.. autosimple:: swh.web.save_origin_webhooks.github.api_origin_save_webhook_github

.. autosimple:: swh.web.save_origin_webhooks.gitlab.api_origin_save_webhook_gitlab

.. autosimple:: swh.web.save_origin_webhooks.sourceforge.api_origin_save_webhook_sourceforge